Prepare the disease specific functions that describe how a change in alcohol consumption gradually has an effect on the relative risk of disease incidence over time (up to 20 years) since alcohol consumption changed.
Usage
AlcLags(disease_name = c("Pharynx", "Oral_cavity"), n_years = 20)Value
Returns a data table with two columns - one for the years since consumption changed, and the other that gives the proportion by which the effect of a change in consumption on an individual's relative risk of disease has so far emerged.
Details
All lag times are taken from the review by Holmes et al. (2012) , and are the numbers used in the current version of SAPM.