Computes the relative risks for each tobacco-related cancer based on the published risk curves.
Value
Returns a numeric vector of each individual's relative risks for the tobacco related disease specified by "disease".
Details
Relative risks for come from published risk functions whose parameters have been hard-coded within this function rather than being read from an external spreadsheet. These relative risks are based on an individual's current smoking intensity. There are others measures of smoking exposure including smoking duration and pack-years, which we will come to think about further.