Parameters to estimate amount drunk on single occasions - Scotland - STAPM version
Source:R/binge_params.R
binge_params_stapm_scot.RdScottish version of `binge_params_stapm` based on the Scottish Health Survey years 2008 to 2019.
Format
A list of four data tables (1 = Negative binomial regression model for the number of weekly drinking occasions, 2 = Fitted Heckman selection model for probability that an individual drinks on at least 3 separate occasions during the diary period, 3 = Fitted Heckman outcome regression results for the standard deviation in the quantity of alcohol consumed in a drinking occasion, 4 = average height and weight)