Computes the probability that each integer number of grams of ethanol per day is consumed on a single drinking occasion.
Usage
intervalprob(
grams_ethanol = 1:540,
SODMean = NULL,
SODSDV = NULL,
SODFreq = NULL,
grams_ethanol_per_unit = 8
)Arguments
- grams_ethanol
Integer vector - the potential grams of ethanol drunk on a single occasion.
- SODMean
Numeric vector - the average amount that each individual is expected to drink on a single drinking occasion.
- SODSDV
Numeric vector - the standard deviation of the amount that each individual is expected to drink on a single drinking occasion.
- SODFreq
Numeric vector - the expected number of drinking occasions that each individual has each week.
- grams_ethanol_per_unit
Numeric value giving the conversion factor for the number of grams of pure ethanol in one UK standard unit of alcohol.