Diseases related to tobacco and their ICD-10 definitions
Source:R/icd10_lookups.R
tob_icd10_lookups.RdDeaths in the mortality data are assigned a single ICD-10 code e.g. C00, but for our analysis we need to group these into cause-groups according to groups e.g. C00-C06. To do this, we define each group by its constituent ICD-10 codes e.g. C00, C01, C02, C03, C04, C05, C06.